DataNotFoundException class

This object is thrown to indicate that the data associated with a particular condition does not exist on Twitter's server.

Inheritance

Constructors

DataNotFoundException(String message, BaseResponse response, [String? body])
Returns the new instance of DataNotFoundException.

Properties

body → String?
The body of the response.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
message → String
The error message
finalinherited
response → BaseResponse
The response from the Twitter API.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited