TwitterException class

This exception indicates that an unexpected error occurred when communicating with the Twitter API.

Implemented types
Implementers

Constructors

TwitterException(String message, BaseResponse response, [String? body])
Returns the new instance of TwitterException.

Properties

body → String?
The body of the response.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
The error message
final
response → BaseResponse
The response from the Twitter API.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited